'use strict';

var path = require('path');
var fs = require('fs');

/**
 * @description 是否是文件夹
 * @param path
 * @returns
 */
const isDir = (path) => {
    return fs.lstatSync(path).isDirectory();
};
/**
 * @description 是否存在文件
 * @param path
 * @returns
 */
const hasFile = (path) => {
    return fs.existsSync(path);
};
/**
 * @description 获取所有文件夹
 * @param path
 * @returns
 */
const getDirs = (path$1) => {
    const dirs = fs.readdirSync(path$1);
    return dirs.reduce((result, name) => {
        const fullPath = path.join(path$1, name);
        isDir(fullPath) && result.push({ dirName: name, dirPath: fullPath });
        return result;
    }, []);
};

function genAlias(root) {
    const dirs = getDirs(root);
    return dirs.reduce((result, item) => {
        const key = `@${item.dirName}`;
        const value = item.dirPath;
        result[key] = value;
        return result;
    }, {});
}
function alias(api) {
    const cwd = api.getCwd();
    const root = path.join(cwd, 'src');
    if (!hasFile(root)) {
        return;
    }
    api.configureWebpack(config => {
        let baseAlias = {};
        if (config.resolve && config.resolve.alias) {
            baseAlias = config.resolve.alias;
        }
        return {
            resolve: {
                alias: { ...genAlias(root), ...baseAlias }
            }
        };
    });
}

module.exports = alias;
